/*********************************************************************************************************
* Software License Agreement (BSD License)                                                               *
* Author: Sebastien Decugis <sdecugis@nict.go.jp>							 *
*													 *
* Copyright (c) 2008, WIDE Project and NICT								 *
* All rights reserved.											 *
* 													 *
* Redistribution and use of this software in source and binary forms, with or without modification, are  *
* permitted provided that the following conditions are met:						 *
* 													 *
* * Redistributions of source code must retain the above 						 *
*   copyright notice, this list of conditions and the 							 *
*   following disclaimer.										 *
*    													 *
* * Redistributions in binary form must reproduce the above 						 *
*   copyright notice, this list of conditions and the 							 *
*   following disclaimer in the documentation and/or other						 *
*   materials provided with the distribution.								 *
* 													 *
* * Neither the name of the WIDE Project or NICT nor the 						 *
*   names of its contributors may be used to endorse or 						 *
*   promote products derived from this software without 						 *
*   specific prior written permission of WIDE Project and 						 *
*   NICT.												 *
* 													 *
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED *
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A *
* PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR *
* ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 	 *
* LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 	 *
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR *
* TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF   *
* ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.								 *
*********************************************************************************************************/

/* Lex sec_nosec extension's configuration parser.
 *
 * The configuration file contains a default priority, and a list of peers with optional overwite priority.
 * -- see the sec_nosec.conf.sample file for more detail.
 */

%{
/* Include the daemon's header files */
#include "sec_nosec.h"
/* Include yacc tokens definitions */
#include "sns_gram.h"

/* Update the column information */
#define YY_USER_ACTION { 					\
	yylloc->first_column = yylloc->last_column + 1; 	\
	yylloc->last_column = yylloc->first_column + yyleng - 1;\
}
%}

%option bison-bridge bison-locations
%option noyywrap

%%

	/* Update the line count */
\n			{
				yylloc->first_line++; 
				yylloc->last_line++; 
				yylloc->last_column=0; 
			}
	 
	/* Eat all spaces */
[[:space:]]+		;
	/* Eat all comments */
#.*$			;

	/* Recognize any integer */
[[:digit:]]+		{
				/* Convert this to an integer value */
				int ret=0;
				ret = sscanf(yytext, "%i", &yylval->integer);
				if (ret != 1) {
					/* No matching: an error occurred */
					log_error("Unable to convert the value '%s' to a valid number: %s\n", yytext, strerror(errno));
					return LEX_ERROR; /* trig an error in yacc parser */
					/* Maybe we could REJECT instead of failing here? */
				}
				return INTEGER;
			}

	/* Recognize the verbosity string */	
(?i:"Debug_Verbosity")	{
				return VERBOSITY;
			}

	/* Recognize the default_priority string */	
(?i:"Default_Priority")	{
				return DEF_PRIO; 
			}

	/* Any other string is considered as a fqdn, if the pattern is valid */
[[:alnum:].-]+		{
				/* Match a fqdn string. expected only ASCII characters, '-' and '.'. The validation of fqdn is done in yacc */
				yylval->string = strdup(yytext);
				if (!yylval->string) {
					log_error("Unable to copy the string '%s': %s\n", yytext, strerror(errno));
					return LEX_ERROR; /* trig an error in yacc parser */
				}
				return STRING;
			}

	/* Valid single characters for yyparse */
[=,;]			{ return yytext[0]; }

	/* Unrecognized sequence */
[^[:space:]=,;\n]+	{ 
				log_error("Unrecognized text on line %d col %d: '%s'.\n", yylloc->first_line, yylloc->first_column, yytext);
			 	return LEX_ERROR; 
			}

%%
